@@ -7,7 +7,8 @@ from contextlib import suppress
 from copy import copy
 from pprint import pprint
 from typing import Any, Dict, List, Optional
-warnings.simplefilter(action='ignore', category=FutureWarning)
+
+warnings.simplefilter(action="ignore", category=FutureWarning)
 # from cytoolz import unique
 
 """
@@ -17,7 +18,7 @@ After working with this. I realized how much I fucked up. Will need to fix this.
 Not only did I not know what I was doing, I rushed it and didn't design correctly.
 
 1. Sharpen the old interfaces (solid variables, consistent abstract classes)
-2. separate code way more
+2. Separate code way more
 3. Make take existing use cases (after I've finished this sprint) and make it easier
 4. Reduce computation requirements with dicts (objects as often as possible)
 5. Make the code super traceable
@@ -25,9 +26,6 @@ Not only did I not know what I was doing, I rushed it and didn't design correctl
     - Maybe have a transition field we write to upon changing tables
     - When you create a schema log the means in which you created that schema. 
     - If you created a schema from a json, take note of that.
-6. Make it more decoupled and composable
-    - Take their styling, and figure out how to give it some magic. 
-    - Use modifiers 
 7. Figure out a better way of dealing with schemas (hashes all the way)
 8. Move away all of the helper functions to different spots
 9. Using classes as parameters to increase certainty in spots
@@ -53,12 +51,11 @@ Not only did I not know what I was doing, I rushed it and didn't design correctl
 23. Prevent fall off conditions for pipes
     - Wrap the copy the current processor when using a wrapped call.
 24. Create a SchemaClass of your own
-    `
-        class RequirementsInteraction:
+    ```py
+        class RequirementsInteraction(Schema):
             # Used to track metadata fields
             description_fields = *fields 
             # Figure out a way to attach a psha to the requirements, even with different variables
-            # Find a 
             field = TypeObject(**parameters) # parameters here describe how the data will be used
             field = TypeObject(**parameters)
             field = TypeObject(**parameters)
@@ -71,8 +68,8 @@ Not only did I not know what I was doing, I rushed it and didn't design correctl
         def prepare(self, redisearch_object):
             # if there was any alter command lately, we would
             pass
-    `
-
+    ```
+25. Write a majority of interation layer in rust
 
 """
 
@@ -85,12 +82,18 @@ from redisearch import Client, Query
 from jamboree import Jamboree
 from jamboree.base.processors.abstracts import Processor
 from jamboree.utils.core import consistent_hash
-from jamboree.utils.support.search import (BaseSearchHandlerSupport,
-                                           InsertBuilder, QueryBuilder,
-                                           is_generic, is_geo, is_nested,
-                                           is_queryable_dict, name_match,
-                                           to_field, to_str)
-
+from jamboree.utils.support.search import (
+    BaseSearchHandlerSupport,
+    InsertBuilder,
+    QueryBuilder,
+    is_generic,
+    is_geo,
+    is_nested,
+    is_queryable_dict,
+    name_match,
+    to_field,
+    to_str,
+)
 
 
 logger.disable(__name__)
@@ -105,6 +108,7 @@ logger.disable(__name__)
 def split_doc(doc):
     return doc.id, ADict(**doc.__dict__)
 
+
 def dictify(doc, is_id=True):
     item = ADict(**doc.__dict__)
     item.pop("super_id", None)
@@ -114,13 +118,15 @@ def dictify(doc, is_id=True):
 
     return item
 
+
 def single_doc_check_convert(doc):
     item = doc.__dict__
     item_conv = ADict(**item)
     item_conv_id = item_conv.pop("id", None)
     item_conv.pop("payload", None)
-    
-    return item_conv, bool(item_conv) 
+
+    return item_conv, bool(item_conv)
+
 
 def doc_convert(doc):
     item = doc.__dict__
@@ -129,6 +135,7 @@ def doc_convert(doc):
     item_conv.pop("payload", None)
     return item_conv
 
+
 class BaseSearchHandler(BaseSearchHandlerSupport):
     def __init__(self):
         super().__init__()
@@ -137,15 +144,14 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
         self.is_replacement = False
         self.current_replacement = None
         self.is_set_entity = False
-                
-        # Subs are all of the subfields we would need to search through
-        self.subs:Dict[str, BaseSearchHandler] = {}
 
+        # Subs are all of the subfields we would need to search through
+        self.subs: Dict[str, BaseSearchHandler] = {}
 
         self.current_doc_id = None
         self.current_doc_id_list = set()
         self.current_client = None
-        
+
         self.print_sub = False
         self.use_sub_query = False
 
@@ -153,20 +159,18 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
         self._sub_ids = []
         self.finished_alter = False
 
-
-
         self.search_sub = False
-        self._processor:Optional[Processor] = None
+        self._processor: Optional[Processor] = None
 
-
-    def __setitem__(self, key:str, value:Any):
+    def __setitem__(self, key: str, value: Any):
         if key not in self.requirements.keys() and (not self.is_replacement):
             return
         self.is_set_entity = False
         self.current_client = None
         if isinstance(value, dict):
-            if len(value) == 0: return
-            self.handle_input_dict_key(key, value) 
+            if len(value) == 0:
+                return
+            self.handle_input_dict_key(key, value)
         else:
             _instance_type = type(value)
             # check that the value is the right type
@@ -175,11 +179,10 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
                 self.query_builder.insert_by_type_str(_str_type, key, value)
                 self.insert_builder.insert_by_type_str(_str_type, key, value)
 
-
     @property
     def replacement(self):
         if self.current_replacement is None:
-            self.current_replacement =  BaseSearchHandler()
+            self.current_replacement = BaseSearchHandler()
             self.current_replacement.is_replacement = True
             self.current_replacement.insert_builder.is_replacement = True
             # self.current_replacement.
@@ -190,11 +193,10 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
         if self._entity is None:
             raise AttributeError("You haven't set entity yet")
         return self._entity
-    
+
     @entity.setter
-    def entity(self, _entity:str):
+    def entity(self, _entity: str):
         self._entity = _entity
-    
 
     @property
     def processor(self):
@@ -203,21 +205,21 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
         return self._processor
 
     @processor.setter
-    def processor(self, _processor:Processor):
+    def processor(self, _processor: Processor):
         self._processor = _processor
         self.set_sub_processors()
 
     @property
     def requirements(self):
         return self._requirements_str
-    
+
     @requirements.setter
-    def requirements(self, _requirements:dict):
+    def requirements(self, _requirements: dict):
         """If we set it here we'd go through each dict item and create string version of each key"""
         # Document id will allow us to figure out which documents are involved with subkeys
-        
-        _requirements['entity'] = str
-        _requirements['super_id'] = str
+
+        _requirements["entity"] = str
+        _requirements["super_id"] = str
         self.process_requirements(_requirements)
         if not self.is_sub_key:
             self.create_sub_handlers()
@@ -225,7 +227,7 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
     @property
     def dreq(self):
         return self._dreq
-    
+
     @dreq.setter
     def dreq(self, _req):
         self._dreq = _req
@@ -236,7 +238,7 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
     @property
     def allrequirements(self):
         return self._dreq
-    
+
     @allrequirements.setter
     def allrequirements(self, _req):
         self._dreq = _req
@@ -251,16 +253,14 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
         return self.current_doc_id
 
     @doc_id.setter
-    def doc_id(self, _doc_id:str):
+    def doc_id(self, _doc_id: str):
         self.current_doc_id = _doc_id
 
-
     @property
     def verbatim(self):
         return self.query_builder.build_exact()
 
     @property
-    @logger.catch(ResponseError)
     def client(self):
         """client
 
@@ -281,12 +281,14 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
         # self.processor
         if self.current_client is None:
             # We would insert a connection here. Use the connection from the search processor to operate.
-            with suppress(ResponseError):
+            with logger.catch(ResponseError):
                 self.current_client = Client(self.index, conn=self.processor.rconn)
-                # print(self.indexable)
                 if len(self.indexable) > 0:
-                    self.current_client.create_index(self.indexable, stopwords=["but", "there", "these", "they", "this", "to"])
-        
+                    self.current_client.create_index(
+                        self.indexable,
+                        stopwords=["but", "there", "these", "they", "this", "to"],
+                    )
+
         if self.is_sub_key:
             if not self.finished_alter:
                 for i in self.indexable:
@@ -294,7 +296,6 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
                         self.current_client.alter_schema_add([i])
                 self.finished_alter = True
 
-
         return self.current_client
 
     @property
@@ -302,20 +303,17 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
         return self.query_builder.general
 
     @general.setter
-    def general(self, term:str):
+    def general(self, term: str):
         """ Push a general term into the query. It can only be done once. Don't put it to a filter key."""
         if not isinstance(term, str):
             logger.error("Term isn't a string")
             return
         self.query_builder.general = term
-    
-    
 
     """
         This is when things get weird
     """
 
-
     def create_sub_handlers(self):
         """ Creates subhandlers for the given index"""
         for name, subkey in self.subfields.items():
@@ -323,7 +321,7 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
             subhandler.is_sub_key = True
             subhandler.index = subkey
             subhandler.insert_builder.is_sub = True
-            
+
             self.replacement.subs[name] = copy(subhandler)
             self.subs[name] = subhandler
 
@@ -338,52 +336,38 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
 
     def set_entity(self):
         if self.is_set_entity is False:
-            self['entity'] = {
+            self["entity"] = {
                 "type": "TEXT",
                 "is_filter": True,
-                "values": {
-                    "is_exact": True,
-                    "term": self.entity
-                }
+                "values": {"is_exact": True, "term": self.entity},
             }
             self.is_set_entity = True
 
-
-
     def verbatim_docs(self):
         built = self.query_builder.build_exact()
-        q = (
-                Query(built)
-                .no_stopwords()
-                .paging(0, 1000000)
-            )
+        q = Query(built).no_stopwords().paging(0, 1000000)
         results = self.client.search(q)
         result_docs = results.docs
         return result_docs
-    
 
     def general_docs(self):
         built = self.query_builder.build()
-        q = (
-                Query(built)
-                .paging(0, 1000000)
-            )
+        q = Query(built).paging(0, 1000000)
         results = self.client.search(q)
         result_docs = results.docs
         return result_docs
 
-    
     def verbatim_sub_ids(self):
         super_id_set = set()
         sub_id_set = set()
-        
+
         for key, sub in self.subs.items():
             sub.print_sub = True
 
             built = sub.query_builder.build()
             # logger.warning(built)
-            built = built.strip(' ')
-            is_falsy = (not built)
+            built = built.strip(" ")
+            is_falsy = not built
             if is_falsy:
                 continue
             # logger.error(built)
@@ -401,15 +385,15 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
                     current_super_ids.append(_super_id)
                 except Exception as e:
                     logger.error(str(e))
-            
+
             if len(current_super_ids) > 0:
                 if len(super_id_set) == 0:
                     super_id_set.update(current_super_ids)
                 else:
                     super_id_set = super_id_set.intersection(current_super_ids)
-            
+
             sub_id_set.update(current_subs)
-        
+
         return list(super_id_set), list(sub_id_set)
 
     def verbatim_doc_ids(self):
@@ -418,7 +402,7 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
         ids = [res.id for res in results.docs]
         return ids
 
-    def handle_input_dict_key(self, name:str, item:dict):
+    def handle_input_dict_key(self, name: str, item: dict):
         """ Figures out where to put the input dictionary for the query """
         if self.is_sub(name):
             # If this is a subkey we'll run the same operation again
@@ -437,19 +421,16 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
             self.insert_builder.from_dict(name, item)
             self.query_builder.from_dict(name, item)
 
-
     def normal_find(self, limit_ids=None):
         built = self.query_builder.build()
         q = Query(built).paging(0, 1000000)
-        # print(built)
-        # print(q.query_string())
         if limit_ids is not None and len(limit_ids) > 0:
             q.limit_ids(*limit_ids)
 
         results = self.client.search(q)
         result_docs = results.docs
         return result_docs
-    
+
     def normal_find_ids(self, limit_ids=None):
         _query = self.query_builder.build()
         q = Query(_query).no_content().paging(0, 1000000)
@@ -457,19 +438,18 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
             q.limit_ids(*limit_ids)
         results = self.client.search(q)
         result_docs = results.docs
-        return [res.id for res in result_docs] 
-
-
+        return [res.id for res in result_docs]
 
     def sub_find(self):
         sup_ids, sub_ids = self.verbatim_sub_ids()
         logger.success((sup_ids, sub_ids))
-        if len(sub_ids) == 0: return []
+        if len(sub_ids) == 0:
+            return []
         results = self.normal_find(limit_ids=sup_ids)
         results_dicts = []
         for result in results:
             _id, idict = split_doc(result)
-            
+
             idict.pop("payload", None)
             subitems = self.keystore.get(_id)
             idict.update(subitems)
@@ -520,13 +500,12 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
             mega_dict.update(key_dict)
         return mega_dict
 
-    
     def find(self):
         """Given the items we've set, find all matching items"""
-        
+
         self.set_entity()
         self.keystore.reset()
-        if self.use_sub_query and self.search_sub: 
+        if self.use_sub_query and self.search_sub:
             return self.sub_find()
         normal = self.normal_find()
         if len(self.subs) == 0:
@@ -535,15 +514,14 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
             return normal
         ndicts = []
         for i in normal:
-            # print(i)
             _i = dictify(i)
             mega = self.find_sub_dictionaries(_i.id)
             if len(mega) > 0:
                 _i.update(mega.to_dict())
             ndicts.append(_i)
         return ndicts
-    
-    def pick(self, _id:str):
+
+    def pick(self, _id: str):
         """ 
             Given an id find the element with the top level id. We aren't searching lower level_ids. 
             
@@ -556,22 +534,21 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
         doc = ADict(**dd)
         _id = doc.pop("id", None)
         doc.pop("payload", None)
-        doc_z = (len(doc) > 0)
+        doc_z = len(doc) > 0
         if len(self.subs) == 0:
             if not doc_z:
                 return None
             doc.update({"id": _id})
             return doc
-        
+
         if doc_z:
             sub_dicts = self.find_sub_dictionaries(_id)
             # if len(sub_dicts) > 0:
             doc.update(sub_dicts)
             doc.update({"id": _id})
             return doc
-        
-        return None
 
+        return None
 
     def update(self):
         """
@@ -588,47 +565,50 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
             doc_ids = self.verbatim_doc_ids()
             batcher = self.client.batch_indexer(chunk_size=len(doc_ids))
             for doc_id in doc_ids:
-                batcher.add_document(doc_id, replace=True, partial=True, **replacement_variables)
+                batcher.add_document(
+                    doc_id, replace=True, partial=True, **replacement_variables
+                )
             batcher.commit()
         else:
             sup_ids, sub_ids = self.verbatim_sub_ids()
             norm_ids = self.normal_find_ids(limit_ids=sup_ids)
             batcher = self.client.batch_indexer(chunk_size=len(norm_ids))
             for doc_id in norm_ids:
-                batcher.add_document(doc_id, replace=True, partial=True, **replacement_variables)
+                batcher.add_document(
+                    doc_id, replace=True, partial=True, **replacement_variables
+                )
             batcher.commit()
 
-
             for sub in self.subs.values():
                 subreplacement = sub.insert_builder.build()
                 if len(subreplacement) > 0:
                     subbatcher = sub.client.batch_indexer(chunk_size=len(sub_ids))
                     for _id in sub_ids:
-                        self.client.add_document(_id, replace=True, partial=True, **subreplacement)
+                        self.client.add_document(
+                            _id, replace=True, partial=True, **subreplacement
+                        )
                     subbatcher.commit()
-    
+
     def update_id(self, _id):
         self.set_entity()
         self.keystore.reset()
         doc = self.client.load_document(_id)
         doc_dict, is_exist = single_doc_check_convert(doc)
-        
+
         if not is_exist:
             return
-        
+
         replacement_variables = self.replacement.insert_builder.build()
-        self.client.add_document(_id, replace=True, partial=True, **replacement_variables)
+        self.client.add_document(
+            _id, replace=True, partial=True, **replacement_variables
+        )
         doc = self.client.load_document(_id)
-        # print(doc)
         # if len(self.subs) > 0:
         #     subreplacement = sub.insert_builder.build()
-        #     print(subreplacement)
 
     # def insert_many(self, list_of_items):
     #     self.client.ba
     #     pass
-    
-    
 
     def insert(self, allow_duplicates=False):
         """
@@ -642,11 +622,9 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
         if self.use_sub_query:
             previous_id = self.sub_insert(allow_duplicates=allow_duplicates)
         else:
-            previous_id, is_add = self.normal_insert(allow_duplicates=allow_duplicates)
+            previous_id, _ = self.normal_insert(allow_duplicates=allow_duplicates)
         return previous_id
 
-
-
     def remove(self):
         """Remove all documents that match a query.
 
@@ -668,16 +646,13 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
             removable = removable.intersection(sup_ids)
             removable = removable.intersection(norm_ids)
 
-
             [self.client.delete_document(_id) for _id in removable]
             for sub in self.subs.values():
                 for _id in sub_ids:
                     sub.client.delete_document(_id)
         else:
             norm_ids = self.normal_find_ids()
-            # print(norm_ids)
             [self.client.delete_document(_id) for _id in norm_ids]
-    
 
     def reset(self):
         """Reset all local variables"""
@@ -688,6 +663,7 @@ class BaseSearchHandler(BaseSearchHandlerSupport):
         self.current_client = None
         self.use_sub_query = False
 
+
 class ExampleSearchHandler(BaseSearchHandler):
     def __init__(self):
         super().__init__()
@@ -698,51 +674,38 @@ class ExampleSearchHandler(BaseSearchHandler):
             "subcategories": dict,
             "secondsub": dict,
             "live": bool,
-            "loc": "GEO"
+            "loc": "GEO",
         }
-        
+
 
 def main():
     logger.enable(__name__)
     processor = Jamboree()
     example_handler = ExampleSearchHandler()
     example_handler.processor = processor
-    example_handler['name'] = "Boi Gurl"
-    example_handler['category'] = "marketsx"
-    example_handler['sample_tags'] = ["four", "five", "six"]
+    example_handler["name"] = "Boi Gurl"
+    example_handler["category"] = "marketsx"
+    example_handler["sample_tags"] = ["four", "five", "six"]
     # TODO: Figure out subcategory update
-    example_handler['subcategories'] = {
+    example_handler["subcategories"] = {
         "hello": "world",
         "country": "US",
     }
-    example_handler['secondsub'] = {
-        "my": "jac"
-    }
-    example_handler.replacement['secondsub'] = {
-        "my": "jack"
-    }
-    example_handler['live'] = False
+    example_handler["secondsub"] = {"my": "jac"}
+    example_handler.replacement["secondsub"] = {"my": "jack"}
+    example_handler["live"] = False
 
     # example_handler.remove()
     example_handler.insert(allow_duplicates=True)
     records = example_handler.find()
-    print("\n\n")
     logger.warning((records, len(records)))
 
     records = example_handler.find()
-    print("\n\n")
     logger.warning((records, len(records)))
 
     records = example_handler.find()
-    print("\n\n")
     logger.warning((records, len(records)))
 
-    # example_handler.update()
-    # records = example_handler.find()
-    # logger.success(records)
-
-
-
 
 if __name__ == "__main__":
     main()
