@@ -137,8 +137,12 @@ class RedisDatabaseZSetsConnection(DatabaseConnection):
         absolute_time_key = f"{_hash}:alist"
         with self.connection.pipeline() as pipe:
             with pipe.lock(rlock):
-                relative_data = {serialized: timing["time"]}
-                absolute_data = {serialized: timing["timestamp"]}
+                relative_data = {
+                    serialized: timing["time"]
+                }
+                absolute_data = {
+                    serialized: timing["timestamp"]
+                }
                 pipe.zadd(relative_time_key, relative_data)
                 pipe.zadd(absolute_time_key, absolute_data)
             pipe.execute()
@@ -166,7 +170,9 @@ class RedisDatabaseZSetsConnection(DatabaseConnection):
                 pipe.zadd(absolute_time_key, absolute_data)
             pipe.execute()
 
-    def save_many(self, query, data: Dict[str, float] = {}, abs_rel="absolute"):
+    def save_many(
+        self, query, data: Dict[str, float] = {}, abs_rel="absolute"
+    ):
         """ 
             # Save Many
 
@@ -230,7 +236,9 @@ class RedisDatabaseZSetsConnection(DatabaseConnection):
         absolute_time_key = f"{_hash}:alist"
 
         with self.connection.lock(rlock):
-            keys = self.connection.zrange(relative_time_key, 0, -1, withscores=True)
+            keys = self.connection.zrange(
+                relative_time_key, 0, -1, withscores=True
+            )
 
             values = [key[0] for key in keys]
             if len(values) == 0:
@@ -280,8 +288,12 @@ class RedisDatabaseZSetsConnection(DatabaseConnection):
                     if count == 0:
                         return []
 
-                    rkeys = pipe.zrange(relative_time_key, 0, -1, withscores=True)
-                    akeys = pipe.zrange(absolute_time_key, 0, -1, withscores=True)
+                    rkeys = pipe.zrange(
+                        relative_time_key, 0, -1, withscores=True
+                    )
+                    akeys = pipe.zrange(
+                        absolute_time_key, 0, -1, withscores=True
+                    )
                     pipe.execute()
                     break
                 except redis.exceptions.WatchError:
@@ -332,7 +344,9 @@ class RedisDatabaseZSetsConnection(DatabaseConnection):
                     if count == 0:
                         return {}
 
-                    keys = pipe.zrange(_current_key, -limit, -1, withscores=True)
+                    keys = pipe.zrange(
+                        _current_key, -limit, -1, withscores=True
+                    )
                     if len(keys) == 0:
                         return {}
                     pipe.execute()
@@ -367,7 +381,10 @@ class RedisDatabaseZSetsConnection(DatabaseConnection):
                         return []
 
                     keys = pipe.zrangebyscore(
-                        _current_key, min=min_epoch, max=max_epoch, withscores=True
+                        _current_key,
+                        min=min_epoch,
+                        max=max_epoch,
+                        withscores=True
                     )
                     pipe.execute()
                     break
@@ -377,7 +394,9 @@ class RedisDatabaseZSetsConnection(DatabaseConnection):
         return combined
 
     def query_all_between(
-        self, _query: dict, abs_rel: str = "absolute",
+        self,
+        _query: dict,
+        abs_rel: str = "absolute",
     ):
         if not self.helpers.validate_query(_query) or abs_rel not in [
             "absolute",
@@ -398,7 +417,10 @@ class RedisDatabaseZSetsConnection(DatabaseConnection):
                         return []
 
                     keys = pipe.zrangebyscore(
-                        _current_key, min=min_epoch, max=max_epoch, withscores=True
+                        _current_key,
+                        min=min_epoch,
+                        max=max_epoch,
+                        withscores=True
                     )
                     pipe.execute()
                     break
@@ -458,7 +480,10 @@ class RedisDatabaseZSetsConnection(DatabaseConnection):
                     if count == 0:
                         return []
                     keys = pipe.zrangebyscore(
-                        _current_key, min="-inf", max=max_epoch, withscores=True
+                        _current_key,
+                        min="-inf",
+                        max=max_epoch,
+                        withscores=True
                     )
                     pipe.execute()
                     break
@@ -482,7 +507,10 @@ class RedisDatabaseZSetsConnection(DatabaseConnection):
                     if count == 0:
                         return []
                     keys = pipe.zrangebyscore(
-                        _current_key, min=min_epoch, max="+inf", withscores=True
+                        _current_key,
+                        min=min_epoch,
+                        max="+inf",
+                        withscores=True
                     )
                     pipe.execute()
                     break
@@ -509,7 +537,8 @@ class RedisDatabaseZSetsConnection(DatabaseConnection):
         _hash_del = f"{_hash}:{delindex}"
 
         serialized_mongo = [
-            orjson.dumps(mon, option=orjson.OPT_SERIALIZE_NUMPY) for mon in mongo_data
+            orjson.dumps(mon, option=orjson.OPT_SERIALIZE_NUMPY)
+            for mon in mongo_data
         ]
         # rlock = f"{_hash}:lock"
         with self.connection.pipeline() as pipe:
